@@ -215,7 +215,8 @@ class Container(ReloadableObjectFromJson):
         tty: bool = False,
         user: Optional[str] = None,
         workdir: Optional[ValidPath] = None,
-    ):
+        stream: bool = False,
+    ) -> Union[None, str, Iterable[Tuple[str, bytes]]]:
         """Execute a command in this container
 
         See the [`docker.container.execute`](../sub-commands/container.md#execute)
@@ -232,6 +233,7 @@ class Container(ReloadableObjectFromJson):
             tty,
             user,
             workdir,
+            stream,
         )
 
     def export(self, output: ValidPath) -> None:
@@ -733,7 +735,8 @@ class ContainerCLI(DockerCLICaller):
         tty: bool = False,
         user: Optional[str] = None,
         workdir: Optional[ValidPath] = None,
-    ) -> Optional[str]:
+        stream: bool = False,
+    ) -> Union[None, str, Iterable[Tuple[str, bytes]]]:
         """Execute a command inside a container
 
         Alias: `docker.execute(...)`
@@ -754,6 +757,7 @@ class ContainerCLI(DockerCLICaller):
                 to write on it.
             user: Username or UID, format: `"<name|uid>[:<group|gid>]"`
             workdir: Working directory inside the container
+            stream: Similar to `docker.run(..., stream=True)`.
 
         # Returns:
             Optional[str]
@@ -774,6 +778,24 @@ class ContainerCLI(DockerCLICaller):
                 "Currently, docker.container.execute(interactive=True) must have"
                 "tty=True. interactive=True and tty=False is not yet implemented."
             )
+
+        if interactive and stream:
+            raise ValueError(
+                "You can't set interactive=True and stream=True at the same"
+                "time. Their purpose are not compatible."
+            )
+
+        if tty and stream:
+            raise ValueError(
+                "You can't set tty=True and stream=True at the same"
+                "time. Their purpose are not compatible."
+            )
+
+        if detach and stream:
+            raise ValueError(
+                "You can't detach and stream at the same time. It's not compatible."
+            )
+
         full_cmd.add_flag("--interactive", interactive)
         full_cmd.add_flag("--privileged", privileged)
         full_cmd.add_flag("--tty", tty)
@@ -784,12 +806,14 @@ class ContainerCLI(DockerCLICaller):
         full_cmd.append(container)
         for arg in to_list(command):
             full_cmd.append(arg)
-
-        result = run(full_cmd, tty=tty)
-        if detach:
-            return None
+        if stream:
+            return stream_stdout_and_stderr(full_cmd)
         else:
-            return result
+            result = run(full_cmd, tty=tty)
+            if detach:
+                return None
+            else:
+                return result
 
     def export(self, container: ValidContainer, output: ValidPath) -> None:
         """Export a container's filesystem as a tar archive
@@ -1290,7 +1314,7 @@ class ContainerCLI(DockerCLICaller):
                 containers with `docker.ps(filters='...')`. The labels can also be found on
                 each container with the attribute `my_container.config.labels`.
             log_driver: Logging driver for the container
-            mac_adress: Container MAC address (e.g., `"92:d0:c6:0a:29:33"`)
+            mac_address: Container MAC address (e.g., `"92:d0:c6:0a:29:33"`)
             memory:  Memory limit, valid values are `1024` (ints are bytes) or
                 `"43m"` or `"6g"`.
             memory_reservation: Memory soft limit
